<template>
  <!-- 驻勤点点名数据 -->
  <div class="station-roll-call-list">
    <div class="query">
      <el-form :inline="true" :model="queryForm" class="query-form">
        <el-form-item label="驻勤点名称">
          <el-input v-model="queryForm.stationName" placeholder="请输入名称"></el-input>
        </el-form-item>
        <el-form-item label="辖区" v-if="this.isSupervision">
          <tree-select
            class="tree-select"
            :options="departs"
            :beforeClearAll="beforeClearDepart"
            placeholder="请选择"
            :normalizer="normalizer"
            v-model="queryForm.depart"
            noOptionsText="无数据"
            noResultsText="无数据"
            @select="onSelectDepart"
          />
        </el-form-item>
        <el-form-item label="驻勤点类型">
          <el-select v-model="queryForm.stationType" clearable placeholder="请选择">
            <el-option v-for="item in stationTypes" :key="item.code" :label="item.name" :value="item.code"> </el-option>
          </el-select>
        </el-form-item>
        <el-form-item label="点名发起人">
          <el-input v-model="queryForm.rollInitiator" placeholder="请输入点名发起人"></el-input>
        </el-form-item>
        <el-form-item label="点名时间">
          <el-date-picker
            v-model="queryForm.rollTime"
            type="datetimerange"
            range-separator="至"
            start-placeholder="开始日期"
            end-placeholder="结束日期"
            value-format="yyyy-MM-dd HH:mm:ss"
            size="small"
          >
          </el-date-picker>
        </el-form-item>
        <el-form-item style="margin-left: 10px">
          <el-button type="primary" @click="querDispatchEmployees">查询</el-button>
          <el-button type="primary" plain @click="resetForm()">重置</el-button>
        </el-form-item>
      </el-form>
    </div>
    <el-table ref="table" :data="tableList" border stripe style="width: 100%" tooltip-effect="dark" height="75%">
      <el-table-column type="index" width="50" label="序号"> </el-table-column>
      <el-table-column align="left" label="驻勤点名称" min-width="200" prop="stationName" show-overflow-tooltip>
      </el-table-column>
      <el-table-column
        align="left"
        label="辖区"
        min-width="220"
        prop="superviseDepartName"
        show-overflow-tooltip
        v-if="this.isSupervision"
      >
      </el-table-column>
      <el-table-column align="left" label="驻勤点类型" min-width="170" prop="stationTypes" show-overflow-tooltip>
        <template slot-scope="scope">
          <span>{{
            stationTypes
              .filter((item) => new Set(scope.row.stationTypes).has(item.code))
              .map((item) => item.name)
              .join(",")
          }}</span>
        </template>
      </el-table-column>
      <el-table-column align="left" label="所属公司" min-width="220" prop="organizationName" show-overflow-tooltip>
      </el-table-column>
      <el-table-column align="left" label="点名时间" min-width="158" prop="createdTime" show-overflow-tooltip> </el-table-column>
      <el-table-column align="left" label="督导点名总人数" min-width="132" prop="countOfMembers" show-overflow-tooltip>
      </el-table-column>
      <el-table-column align="left" label="成功人数" min-width="82" prop="countOfSuccess" show-overflow-tooltip>
      </el-table-column>
      <el-table-column align="left" label="失败人数" min-width="82" prop="countOfFailed" show-overflow-tooltip> </el-table-column>
      <el-table-column align="left" label="点名发起人" min-width="100" prop="actionEmployeeName" show-overflow-tooltip>
      </el-table-column>
      <el-table-column align="center" label="操作" width="87">
        <template slot-scope="scope">
          <div class="table-btn">
            <el-button type="text" @click="checkRow(scope.row)"> 查看 </el-button>
          </div>
        </template>
      </el-table-column>
    </el-table>
    <el-pagination
      class="pagination"
      :current-page="queryForm.pageNum"
      :page-size="queryForm.pageSize"
      :page-sizes="[10, 20, 30, 50]"
      :total="total"
      layout="total, prev, pager, next, sizes"
      @size-change="listSizeChange"
      @current-change="listCurrentChange"
    >
    </el-pagination>
  </div>
</template>

<script>
import _ from "lodash";
import treeSelect from "@riophae/vue-treeselect";
import "@riophae/vue-treeselect/dist/vue-treeselect.css";
import { getAllStationTypes } from "@/api/security-station-controller";
import { getDeparts } from "@/api/departs-controller";
import { getRollCallEmployeesGroup } from "@/api/roll-call-controller";
export default {
  name: "stationRollCallList",
  components: {
    treeSelect,
  },
  props: {
    data: Object,
  },
  data() {
    return {
      isSupervision: false, //是否监管端 显示辖区：企业账号进来不展示【辖区】筛选项:false，只有监管账号进来才展示:true
      deskTypes:
        localStorage.getItem("platform") === "2"
          ? ["Proprietor"]
          : localStorage.getItem("platform") === "3"
          ? ["TemporarySecurity"]
          : ["Normal"],
      queryForm: {
        pageNum: 1,
        pageSize: 10,
        stationName: "",
        stationType: "", //驻勤点类型
        depart: null, //辖区
        superviseDepartIds: [],
        rollInitiator: "", //点名发起人
        rollTime: "", //点名时间
      },
      stationTypes: [],
      departs: [],
      normalizer(node) {
        if (node.children && !node.children.length) {
          delete node.children;
        }
        return {
          id: node.code,
          label: node.name,
          children: node.children,
          // isDisabled: !node.selectable,
          isDisabled: false,
        };
      },
      tableList: [],
      total: 0,
    };
  },
  methods: {
    async init() {
      this.stationTypes = await getAllStationTypes({ deskTypes: [] }); //获取驻勤点信息
      console.log("stationTypes", this.stationTypes);
      this.departs = await getDeparts({ deskTypes: this.deskTypes }); // 获取辖区树
      console.log("departs", this.departs);
      const userInfo = localStorage.getItem("userInfo");
      let userInfoJson;
      if (userInfo) {
        userInfoJson = JSON.parse(userInfo);
      }
      if (userInfoJson) {
        this.isSupervision = JSON.parse(userInfo).superviseDesk; //判断身份 ture:监管账户；false:企业账户
      }
      this.querDispatchEmployees();
    },
    querDispatchEmployees() {
      let params = {
        pageIndex: this.queryForm.pageNum,
        pageSize: this.queryForm.pageSize,
        forExport: true,
        stationName: this.queryForm.stationName,
        superviseDepartIds: this.queryForm.superviseDepartIds,
        stationTypes: this.queryForm.stationType ? [this.queryForm.stationType + ""] : [],
        actionEmployeeName: this.queryForm.rollInitiator,
        beginDate: this.queryForm.rollTime ? this.queryForm.rollTime[0] : "",
        endDate: this.queryForm.rollTime ? this.queryForm.rollTime[1] : "",
        callTypes: ["Dispatch"], //Dispatch
      };
      getRollCallEmployeesGroup(params)
        .then((res) => {
          console.log("querRollCallEmployeesDispatch", res);
          this.tableList = res.data;
          this.total = res.totalCount;
        })
        .catch((err) => {
          console.log(err);
        });
    },
    resetForm() {
      Object.assign(this.$data.queryForm, this.$options.data().queryForm);
    },
    listSizeChange(val) {
      this.queryForm.pageSize = val;
      this.queryForm.pageNum = 1;
      this.querDispatchEmployees();
    },
    listCurrentChange(val) {
      this.queryForm.pageNum = val;
      this.querDispatchEmployees();
    },
    checkRow(row) {
      this.$emit("toPersonCardList", row);
    },
    onSelectDepart(node) {
      console.log(node);
      if (node?.children?.length > 0) {
        const getTail = (item) => (item.children && item.children.length > 0 ? item.children.map((m) => getTail(m)) : [item]);
        const result = _.flattenDeep(node.children.map((m) => [m, ...getTail(m)]));
        console.log(" log result", result);
        this.queryForm.superviseDepartIds = [node.code, ...result.map((x) => x.code)];
      } else {
        this.queryForm.superviseDepartIds = [node.code];
      }
    },
    beforeClearDepart() {
      this.queryForm.depart = null;
      this.queryForm.superviseDepartIds = [];
    },
  },
  mounted() {
    this.init();
  },
};
</script>

<style scoped lang="scss">
.tree-select {
  //padding-top: 6px;
  width: 400px;
  // font-size: 14px;
  line-height: 35px;
  // font-family: PingFang SC-Regular, PingFang SC;
  // font-weight: 400;
  color: #606266;
  .vue-treeselect__placeholder {
    line-height: 35px;
  }
  .vue-treeselect__control {
    height: 35px !important;
  }
  .vue-treeselect__placeholder,
  .vue-treeselect__single-value {
    line-height: 35px;
  }
}
.station-roll-call-list {
  width: 100%;
  height: 100%;
  .query {
    width: 100%;
    height: 140px;
    background: #f5faff;
    box-shadow: 0px 2px 8px 0px rgba(0, 0, 0, 0.04);
    margin-bottom: 24px;
    padding: 24px;
    display: flex;
    flex-direction: column;
    flex-wrap: wrap;
    justify-content: space-between;
  }
}
</style>
